@@ -7,7 +7,7 @@ use warnings;
 use Kwiki::Plugin -Base;
 use mixin 'Kwiki::Installer';
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 const class_id => 'disable_wiki_names';
 const class_title => "Disable WikiNames auto markup";
@@ -22,18 +22,19 @@ sub register {
     $registry->add(hook => 'page:kwiki_link', pre => 'dwn_uri_hook');
 }
 
-sub dwn_uri_hook {           ## Adopted from Kwiki::CoolURI.pm 
+sub dwn_uri_hook {   ## Adopted from Kwiki::CoolURI
     my $hook = pop;
     $hook->code(undef);
-    my ($label) = @_;  
-    $label = $self->title     
-      unless defined $label;  
-    my $class = $self->active 
-      ? '' : ' class="empty"';
-    qq($label);
+    my ($label) = @_;
+    my $page_uri = $self->uri;
+    if(!defined $label) {
+      qq($page_uri);
+    } else {
+      my $class = $self->active? '' : ' class="empty"';
+      qq(<a href="$page_uri"$class>$label</a>);
+    }
 }
 
-
 1;
 __END__
 =head1 NAME
